package com.triennium.sonic.xmlvalidation;

import java.io.File;
import java.util.concurrent.Callable;

import org.xml.sax.ErrorHandler;
import org.xml.sax.helpers.DefaultHandler;

/** An abstract superclass of an external XML validator. It is able to check
 * a given XML file against a specified XML schema without an internal reference
 * in the XML file's head. The main functionality lies in the function
 * {@link #validate(File)}, while some properties must be set beforehand 
 * ({@link #setSchema(File)}, {@link #setErrorHandler(DefaultHandler)}).
 * 
 */

public abstract class AbstractValidator implements Callable{
    /** Value: "http://java.sun.com/xml/jaxp/properties/schemaLanguage" */
    protected static final String JAXP_SCHEMA_LANGUAGE = "http://java.sun.com/xml/jaxp/properties/schemaLanguage";
    /** Value: "http://java.sun.com/xml/jaxp/properties/schemaSource" */
    protected static final String JAXP_SCHEMA_SOURCE = "http://java.sun.com/xml/jaxp/properties/schemaSource";
    /** Value: "http://www.w3.org/2001/XMLSchema" */
    protected static final String W3C_XML_SCHEMA = "http://www.w3.org/2001/XMLSchema";
    
    /** default is PlainErrorHandler (checked in {@link #validate(File)}). */
    protected DefaultHandler errorHandler = null;
    /** A XML schema to validate the target XML files. */
    protected String schema = null;
    
    /**
     * Validates the given xml file using an external schema.
     * @see #setSchema(File)
     * @see #setErrorHandler(DefaultHandler)
     * @throws Exception should be thrown when the necessary properties (schema
     * and error handler) have not been set.
     * @return true when the given file complies the schema, false otherwise
     */
    public abstract boolean validate(File xmlFile) throws Exception;
    
    /** Setter for the schema property.
     */
    public void setSchema(String schema) {
        this.schema = schema;
    }
    
    /** Getter for the schema property.
     */
    public String getSchema() {
        return this.schema;
    }
    
    /** Setter for the errorHandler property.
     */
    public void setErrorHandler(DefaultHandler newHandler) {
        this.errorHandler = newHandler;
    }
    
    /** Getter for the errorHandler property.
     */
    public ErrorHandler getErrorHandler() {
        return this.errorHandler;
    }
}

